@@ -2,11 +2,10 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "identity.h"
+
 #include "abstractaccount.h"
 #include "relationship.h"
 
-#include <QJsonObject>
-
 using namespace Qt::Literals::StringLiterals;
 
 QString Identity::displayName() const
@@ -167,3 +166,5 @@ QUrl Identity::url() const
 {
     return m_url;
 }
+
+#include "moc_identity.cpp"
\ No newline at end of file
