@@ -20,6 +20,10 @@ public:
     /// \param account The account the notification belongs to
     void handle(std::shared_ptr<Notification> notification, AbstractAccount *account);
 
+Q_SIGNALS:
+    void lastNotificationClosed();
+
 private:
     QNetworkAccessManager *m_nam;
+    QMetaObject::Connection m_lastConnection;
 };
