@@ -3,11 +3,10 @@
 
 #pragma once
 
-#include <QObject>
-#include <QtQml/qqmlregistration.h>
+#include <QJSEngine>
 
-class Identity;
-class Post;
+#include "identity.h"
+#include "post.h"
 
 class Navigation : public QObject
 {
@@ -15,6 +14,16 @@ class Navigation : public QObject
     QML_ELEMENT
     QML_SINGLETON
 
+public:
+    static Navigation *create(QQmlEngine *, QJSEngine *)
+    {
+        auto inst = &instance();
+        QJSEngine::setObjectOwnership(inst, QJSEngine::ObjectOwnership::CppOwnership);
+        return inst;
+    }
+
+    static Navigation &instance();
+
 Q_SIGNALS:
     void openStatusComposer();
     void replyTo(const QString &inReplyTo, const QVariant &mentions, int visibility, Identity *authorIdentity, Post *post);
@@ -22,4 +31,10 @@ Q_SIGNALS:
     void openThread(const QString &postId);
     void openFullScreenImage(const QVariant &attachments, Identity *identity, int currentIndex);
     void openTag(const QString &tag);
+    void reportPost(Identity *identity, const QString &postId);
+    void reportUser(Identity *identity);
+    void openList(const QString &listId, const QString &listName);
+
+private:
+    Navigation() = default;
 };
